@@ -414,9 +414,12 @@ fn handle_merge<
             if let Some(other) = incr_other {
                 let mut curs = P::cursor_first(&other);
                 let left = P::left_child(other.as_page(), &curs);
-                txn.incr_rc(left)?;
+                if left > 0 {
+                    txn.incr_rc(left)?;
+                }
                 while let Some((k0, v0, r)) = P::next(txn, other.as_page(), &mut curs) {
                     for o in k0.page_references().chain(v0.page_references()) {
+                        assert!(o > 0);
                         txn.incr_rc(o)?;
                     }
                     if r != 0 {
@@ -429,6 +432,7 @@ fn handle_merge<
             // increment its references.
             if let Some((ref k, ref v)) = incr_mid {
                 for o in k.page_references().chain(v.page_references()) {
+                    assert!(o > 0);
                     txn.incr_rc(o)?;
                 }
             }
@@ -551,6 +555,7 @@ fn handle_merge<
                     .page_references()
                     .chain(split_value.page_references())
                 {
+                    assert!(o > 0);
                     txn.incr_rc(o)?;
                 }
             }
