@@ -341,7 +341,7 @@ impl<K: Storable + core::fmt::Debug, V: Storable + core::fmt::Debug> super::BTre
 
     unsafe fn put_mut(
         page: &mut MutPage,
-        c: &Self::Cursor,
+        c: &mut Self::Cursor,
         k0: &K,
         v0: &V,
         r: u64,
@@ -353,6 +353,7 @@ impl<K: Storable + core::fmt::Debug, V: Storable + core::fmt::Debug> super::BTre
         } else {
             Internal::alloc_write(page, k0, v0, 0, r, &mut n);
         }
+        c.total += 1;
     }
 
     unsafe fn set_left_child(
